-- **************************************************************************
-- * AdvancedTradeSkillWindow_Levels.lua
-- *
-- * Originally By Yammy
-- * Adopted by HonorGoG of the Titan Development Team
-- **************************************************************************
-- * 2009-04-25 : 3.0.3.30100 Error fixing
-- * 2009-04-22 : 3.0.2.30100 Error fixing and code optimization
-- * 2009-04-20 : 3.0.1.30100 Error fixing and code optimization
-- * 2009-04-19 : 3.0.0.30100 Adopted and released for WoW 3.1
-- **************************************************************************

-- ******************************** Constants *******************************
local ATSWL_DEBUG = false

-- ******************************** Variables *******************************

-- ******************************** Functions *******************************

function ATSWLGetRecipeLevel(index)
     ATSWL_DebugFunc("ATSWLGetRecipeLevel", {index});
     local numSkills = GetNumTradeSkills()
     ATSWL_DebugFunc("GetNumTradeSkills", {numSkills});
     local firstSkill = GetFirstTradeSkill()
     ATSWL_DebugFunc("GetFirstTradeSkill", {firstSkill});
     if ( numSkills < index or index == nil or numSkills == 0 or firstSkill == 0 ) then
          return nil;
     end
     ATSWL_DebugFunc("GetTradeSkillItemLink", {index});
     local link = GetTradeSkillItemLink(index);
     ATSWL_DebugFunc("GetItemInfo", {link});
     -- name, link, quality, iLevel, reqLevel, type, subType, maxStack, equipSlot, texture = GetItemInfo(data);
     local name, _, _, _, reqLevel = GetItemInfo(link);
     ATSWL_DebugFunc("GetItemInfo_name:", {name});
     ATSWL_DebugFunc("GetItemInfo_reqLevel::", {reqLevel});
     if ( reqLevel ~= nil and reqLevel ~= 0 ) then
     	return "[L".. string.format( "%02d", reqLevel ) .. "]";
     else
     	return
     end
end

-- **************************************************************************
-- NAME : ATSWL_DebugFunc(func, args)
-- DESC : Display function and arguments if debug mode is active
-- VARS : func = name of the function, args = arguments passed to function
-- **************************************************************************
function ATSWL_DebugFunc(func, args)
     local argstring = "(";
     if args then
          for i=1, table.getn(args) do
               if (not (i==1)) then argstring = argstring.. ", "; end
               argstring = argstring.. args[i];
          end
     end
     argstring = argstring.. ")";
     if (ATSWL_DEBUG) then DEFAULT_CHAT_FRAME:AddMessage("ATSWL: ".. func.. argstring); end
end

-- **************************************************************************
-- NAME : ATSWL_Debug(msg)
-- DESC : Display message if debug mode is active
-- VARS : msg = message to display
-- **************************************************************************
function ATSWL_Debug(msg)
     if (ATSWL_DEBUG) then DEFAULT_CHAT_FRAME:AddMessage("ATSWL: ".. msg); end
end

-- **************************************************************************
-- Main Loop and Primary Hook
-- **************************************************************************

DEFAULT_CHAT_FRAME:AddMessage("|cffffd700ATSW_|cffbb33bbLevels |cffffd7003.0.3.30100 Loaded|r");

local hooked_GetTradeSkillInfo = GetTradeSkillInfo;

function GetTradeSkillInfo(index)
	ATSWL_DebugFunc("GetTradeSkillInfo", {index});
     local numSkills = GetNumTradeSkills()
	ATSWL_DebugFunc("numSkills:", {numSkills});
	local skillName, skillType, numAvailable, isExpanded, altVerb = hooked_GetTradeSkillInfo(index);
	if ( skillName ~= nil ) then ATSWL_Debug("GetTradeSkillInfo_skillName:".. skillName); else ATSWL_Debug("GetTradeSkillInfo_skillName: nil");end
	if ( skillType ~= nil ) then ATSWL_Debug("GetTradeSkillInfo_skillType:".. skillType); else ATSWL_Debug("GetTradeSkillInfo_skillType: nil");end
	if ( numAvailable ~= nil ) then ATSWL_Debug("GetTradeSkillInfo_numAvailable:".. numAvailable); else ATSWL_Debug("GetTradeSkillInfo_numAvailable: nil");end
	if ( isExpanded ~= nil ) then ATSWL_Debug("GetTradeSkillInfo_isExpanded:".. isExpanded); else ATSWL_Debug("GetTradeSkillInfo_isExpanded: nil");end
	if ( skillType ~= "header" and numSkills ) then
		level = ATSWLGetRecipeLevel(index);
		if ( level ~= nil and skillName ~= nil ) then
			skillName = level .. " " .. skillName;
		end
	end
	ATSWL_DebugFunc("GetTradeSkillInfo", {level});
	return skillName, skillType, numAvailable, isExpanded, altVerb;
end
